@@ -2,9 +2,13 @@
 if __name__ == "__main__":
     from gitee import GiteeRepo
     from urlparse import URL
+    from crypto import CryptoHandler
+    from exceptions import ColumnDataDoesNotFit, ColumnNotFoundError
 else:
+    from .crypto import CryptoHandler
     from .gitee import GiteeRepo
     from .urlparse import URL
+    from .exceptions import ColumnDataDoesNotFit, ColumnNotFoundError
 
 import json, warnings
 
@@ -19,6 +23,15 @@ class table_objects:
         return self.obj.columns
     
     def get(self, *args, **kwargs):
+        """ Usage: get(**namespace) """
+        if len(kwargs) == 1 and hasattr(kwargs, self.obj.index):
+            return SqleeColumn(
+                    url = self.obj.url / column,
+                    repo = self.obj.repo,
+                    index = self.obj.index,
+                    table = self.obj,
+                    namespace = self.obj.namespace,
+                    )
         need = len(kwargs)
         result = []
         for column in self.obj.columns:
@@ -33,34 +46,29 @@ class table_objects:
         return result[0]
 
     def create(self, *args, **kwargs):
-        column = self.obj.repo.list_folder(path=self.obj.name, int=True)
-        if len(column) == 0:
-            column = 0
-        else:
-            column = max(column) + 1
+        """ Usage: create(**namespace) """
+        column = self._get_cloumn(kwargs)
+        all_columns = self.obj.repo.list_file(self.obj.name)
 
-        self.obj.repo.make_folder(path=URL(self.obj.name)/column)
+        if str(column) in all_columns:
+            raise ValueError("目标索引已存在.")
 
         datas = []
-        for name in self.obj.namespace:
-            if name == "id":
+        for namespace in self.obj.namespace:
+            if namespace == self.obj.index:
                 continue
-            if name in kwargs:
-                i = (self.obj.namespace.index(name) - 1)
-                if i < 0:
-                    raise ValueError("INDEX 值小于目标阈值，不可跳过.")
-                self.obj.repo.upload_file(
-                    path = URL(self.obj.name) / column / i,
-                    content = json.dumps({"content": kwargs[name]})
-                    )
-            else:
-                raise ValueError("意料之外的参数: %s." % name)
+            datas.append(kwargs[namespace])
 
+        self.obj.repo.upload_file(
+            path = URL(self.obj.name) / column,
+            content = self.obj.crypto.encrypt_to_str(json.dumps(datas))
+            )
+        
         self.obj.sync()
         return self.obj.columns
 
     def delete(self):
-        self.obj.delete()
+        return self.obj.delete()
     
     @property
     def length(self):
@@ -70,6 +78,15 @@ class table_objects:
         return len(self.obj.columns)
     
     def filter(self, *args, **kwargs):
+        if len(kwargs) == 1 and self.obj.index in kwargs:
+            return [SqleeColumn(
+                    path = URL(self.obj.name) / kwargs[self.obj.index],
+                    repo = self.obj.repo,
+                    index = self.obj.index,
+                    table = self.obj,
+                    index_data = kwargs[self.obj.index],
+                    namespace = self.obj.namespace,
+                    )]
         need = len(kwargs)
         result = []
         for column in self.obj.columns:
@@ -81,62 +98,35 @@ class table_objects:
                 result.append(column)
         return result
 
-class SqleeData:
-    data = None
-    url = None
-    repo = None
-    id = None
-    def __init__(self, data, url=None, repo=None, namespace=[]):
-        if not isinstance(url, str) and not isinstance(url, URL):
-            raise ValueError("参数'url'必须是字符串.")
-        if not isinstance(repo, GiteeRepo):
-            raise ValueError("参数'repo'必须是GiteeRepo.")
-        self.data = data
-        self.url = url
-        self.repo = repo
-        self.namespace = namespace
+    def _get_cloumn(self, kwargs):
+        if self.obj.index == "id":
+            column = self.obj.repo.list_file_int(path=self.obj.name)
+            if len(column) == 0:
+                column = 0
+            else:
+                column = max(column) + 1
+            return column
+        else:
+            if self.obj.index in kwargs:
+                return kwargs[self.obj.index]
+            else:
+                raise ValueError("未传入索引数据 %s." % self.obj.index)
 
-    @property
-    def type(self):
-        return type(self.data)
-
-    def update(self, data=None):
-        splited_url = self.url.split("/")
-        answer = self.repo.update_file(
-            path = str(URL(splited_url[-3])/splited_url[-2]/splited_url[-1]),
-            content = json.dumps({"content": data})
-            )
-        self.data = data
-        return answer
-
-    def delete(self):
-        answer = self.repo.delete_file(
-            path = str(URL(splited_url[-3])/splited_url[-2]/splited_url[-1])
-            )
-        del self
-        return answer
-
-    def __str__(self):
-        return self.data
+    def sync(self):
+        return self.obj.sync()
 
 class SqleeColumn:
     datas = []
-    repo = None
-    table = None
-    id = None
-    def __init__(self, url=None, repo=None, id=None, table=None,
-                 namespace=[], *args, **kwargs):
-        if not isinstance(url, str) and not isinstance(url, URL):
-            raise ValueError("参数'url'必须是字符串或URL.")
-        if not isinstance(id, int):
-            raise ValueError("参数'id'必须是整型数.")
+    def __init__(self, path=None, repo=None, index=None, index_data=None, 
+                 table=None, namespace=[], *args, **kwargs):
         if not isinstance(repo, GiteeRepo):
             raise ValueError("参数'repo'必须是GiteeRepo.")
 
-        self.id = id
+        self.index = index
+        self.index_data = index_data
         self.repo = repo
         self.table = table
-        self.url = url
+        self.path = path
         self.namespace = namespace
         self.sync()
 
@@ -152,55 +142,50 @@ class SqleeColumn:
         return len(self.data)
 
     def sync(self):
-        self.datas = [self.id, ]
+        self.datas = [self.index_data, ]
 
-        datas = []
-        queries = list(self.repo.list_file(path="%s/%d" % (self.table.name, self.id), detail=True))
-        for query in queries:
-            if query["type"] == "file" and query["name"] != ".keep":
-                datas.append(query)
+        datas = json.loads(self.table.crypto.decrypt_by_str(
+            self.repo.get_file(path=self.path)
+            ))
 
         for data in datas:
-            loads = self.repo.get_data(path=data["path"])
-            self.__setattr__(self.namespace[int(data["name"]) + 1], loads)
-            self.datas.append(
-                SqleeData(loads, url=data["url"],
-                          namespace=self.namespace[int(data["name"]) + 1],
-                          repo=self.repo)
-                )
+            setattr(self, self.namespace[datas.index(data)], data)
+        self.datas += datas
 
         if len(self.datas) != len(self.namespace):
-            wanings.warn(
-                ColumnDataDoesNotFit
-                )
-        self.datas = tuple(self.datas)
+            print(ColumnDataDoesNotFit(namespace=self.namespace, datas=self.datas))
         return self.datas
 
     def update(self, *args, **kwargs):
         for kwarg in kwargs:
-            self.datas[self.namespace.index(kwarg)].update(data=kwargs[kwarg])
-        self.sync()
-        return self.datas
+            self.datas[self.namespace.index(kwarg)] = kwargs[kwarg]
+        self.repo.update_file(
+            path = self.path,
+            content = self.table.crypto.encrypt_to_str(json.dumps(self.datas))
+            )
+        return self.sync()
 
     def delete(self):
-        for data in self.datas:
-            self.datas[self.datas.index(data)].delete()
         del self
         return True
 
 class SqleeTable:
     columns = []
-    def __init__(self, name=None, repo=None):
+    def __init__(self, name=None, repo=None, directly_load=True, encrypt=True):
         if not isinstance(name, str) and not isinstance(name, URL):
-            raise ValueError("参数'name'必须是字符串或URL.")
+            raise ValueError("参数 'name' 必须是字符串或URL.")
         if not isinstance(repo, GiteeRepo):
-            raise ValueError("参数'repo'必须是GiteeRepo.")
+            raise ValueError("参数 'repo' 必须是GiteeRepo.")
 
+        self.crypto = CryptoHandler(crypto=encrypt)
         self.name = name
         self.repo = repo
+        self.namespace = json.loads(self.repo.get_file(path=URL(self.name)/".namespace"))
+        self.index = self.namespace[0]
         self.url = URL()/self.repo.user/self.repo.repo/self.name
-        self.sync()
         self.objects = table_objects(obj=self)
+        if directly_load:
+            self.sync()
     
     def get_column(self, id=None):
         for column in self.columns:
@@ -209,19 +194,18 @@ class SqleeTable:
         else:
             raise ColumnNotFoundError(id)
 
-    def insert(self, datas=None):
-        return self.objects.create(datas=datas)
+    def insert(self, *args, **kwargs):
+        return self.objects.create(*args, **kwargs)
 
     def sync(self):
-        self.namespace = ["id", ]
-        self.namespace += json.loads(self.repo.get_file(path=URL(self.name)/".namespace"))
         self.columns = []
-        for column in self.repo.list_folder_int(path=self.name):
+        for column in self.repo.list_file_int(path=self.name):
             self.columns.append(
                 SqleeColumn(
-                    url = self.url / column,
+                    path = URL(self.name) / column,
                     repo = self.repo,
-                    id = int(column),
+                    index = self.namespace[0],
+                    index_data = column,
                     table = self,
                     namespace = self.namespace,
                     )
